<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title>{{{{ SITE.name }}}} - {{{{ page_title }}}}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" href="{{{{ STATIC_URL }}}}css/screen.css">
</head>

<body>
    {{% block base_content %}}{{% endblock %}}
</body>
</html>
